#include <tagcoll/experiments.h>
#include <tagcoll/Serializer.h>
#include <tagcoll/TextFormat.h>
#include <tagcoll/StdioParserInput.h>

#include <iostream>

#include <stdarg.h>

using namespace std;
using namespace Tagcoll;

int main (int argc, char *argv[])
{
	try {
		// Install the handler for unexpected exceptions
		InstallUnexpected installUnexpected;
		TrivialConverter<string, string> conv;
		Graph<string, string> graph;
		StdioParserInput in(stdin, "(stdin)");

		TextFormat<string, string>::parse(conv, conv, in, graph);

		graph.buildGraphs("graph-dist1", 1);

		//TextFormat<string, string> writer(conv, conv, stdout);
		//graph.output(writer);

		return 0;
	} catch (Exception& e) {
		fprintf(stderr, "%s: %.*s\n", e.type(), PFSTR(e.desc()));
	}
}

// vim:set ts=4 sw=4:
